<?php
/*
 * ----------------------------------------------------------------------------
 * Va-ChannelX.inc.php                                               12/17/2008
 * This script will retrieve all of the informaton related to the configured
 * channels.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2006 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('include_dir.php');                    // Get include directory.
require_once($includeDir . 'va-functions.inc.php'); // A VADV-PHP script.


/**
* Va-ChannelX.inc.php :: GetChannels()
*
* Retrieve all of the channel information and store it into a
* multidimensional array.
*
* Array format: $channels[1]['setting']
*               $channels[0] = Total number of nodes.
*
* @return array
*/
function GetChannels() {
    $fileString = ReadChannels();
    if ($fileString === FALSE) {
        trigger_error(VA_Error(3));
    }

    $channels = array();                    // Create the array.
    $offset   = 0;

    for ($i = 1; $offset < strlen($fileString); $i++) {
        $channels[$i]['init1']      = GetString($fileString, 1 + $offset, 40);
        $channels[$i]['init2']      = GetString($fileString, 41 + $offset, 40);
        $channels[$i]['init3']      = GetString($fileString, 81 + $offset, 40);
        $channels[$i]['answer']     = GetString($fileString, 121 + $offset, 20);
        $channels[$i]['dial']       = GetString($fileString, 141 + $offset, 20);
        $channels[$i]['offhook']    = GetString($fileString, 161 + $offset, 20);
        $channels[$i]['baudrate']   = GetLongInt($fileString, 181 + $offset);
        $channels[$i]['lockedbaud'] = GetInteger($fileString, 185 + $offset);
        $channels[$i]['rtscts']     = GetInteger($fileString, 187 + $offset);
        $channels[$i]['serialport'] = GetInteger($fileString, 189 + $offset);
        $channels[$i]['porttype']   = GetInteger($fileString, 191 + $offset);
        $channels[$i]['baseaddy']   = dechex(GetInteger($fileString, 193 + $offset));
        $channels[$i]['irq']        = dechex(GetInteger($fileString, 195 + $offset));
        $channels[$i]['minbaud']    = GetLongInt($fileString, 197 + $offset);
        $channels[$i]['extra']      = GetString($fileString, 199 + $offset, 4);

        $offset = 204 * $i;
    }

    $channels[0] = $i - 1;                  // Put the number of channels in position 0.

    return $channels;                       // Return the channel information.

}


/**
* Va-ChannelX.inc.php :: PutChannels()
*
* This function will change the channelx.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]['setting'].
*
* @param string $fileString
* @param array $configVariable
* @return string
*/
function PutChannels($fileString,
                     $configVariable) {
    if ($fileString === FALSE) {
        return FALSE;
    }

    if (!is_string($fileString)) {
        $fileString = (string) $fileString;
    }
    if (!is_array($configVariable)) {
        trigger_error(VA_Error(1));
    }

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.
    $offset  = 0;

    if (isset($configVariable[0])) {
        $length--;
    }

    for ($i = 1; $pointer < $length; $i++) {
        $total = intval(strlen($fileString) / 204);
        if ($i > $total) {
            $fileString = $fileString . str_pad('', 204, chr(0));
        }

        if (isset($configVariable[$i])) {
            $pointer++;
            if (isset($configVariable[$i]['init1']))      $fileString = PutString($fileString, $configVariable[$i]['init1'], 1 + $offset, 40);
            if (isset($configVariable[$i]['init2']))      $fileString = PutString($fileString, $configVariable[$i]['init2'], 41 + $offset, 40);
            if (isset($configVariable[$i]['init3']))      $fileString = PutString($fileString, $configVariable[$i]['init3'], 81 + $offset, 40);
            if (isset($configVariable[$i]['answer']))     $fileString = PutString($fileString, $configVariable[$i]['answer'], 121 + $offset, 20);
            if (isset($configVariable[$i]['dial']))       $fileString = PutString($fileString, $configVariable[$i]['dial'], 141 + $offset, 20);
            if (isset($configVariable[$i]['offhook']))    $fileString = PutString($fileString, $configVariable[$i]['offhook'], 161 + $offset, 20);
            if (isset($configVariable[$i]['baudrate']))   $fileString = PutLongInt($fileString, $configVariable[$i]['baudrate'], 181 + $offset);
            if (isset($configVariable[$i]['lockedbaud'])) $fileString = PutInteger($fileString, $configVariable[$i]['lockedbaud'], 185 + $offset);
            if (isset($configVariable[$i]['rtscts']))     $fileString = PutInteger($fileString, $configVariable[$i]['rtscts'], 187 + $offset);
            if (isset($configVariable[$i]['serialport'])) $fileString = PutInteger($fileString, $configVariable[$i]['serialport'], 189 + $offset);
            if (isset($configVariable[$i]['porttype']))   $fileString = PutInteger($fileString, $configVariable[$i]['porttype'], 191 + $offset);
            if (isset($configVariable[$i]['baseaddy']))   $fileString = PutInteger($fileString, hexdec($configVariable[$i]['baseaddy']), 193 + $offset);
            if (isset($configVariable[$i]['irq']))        $fileString = PutInteger($fileString, hexdec($configVariable[$i]['irq']), 195 + $offset);
            if (isset($configVariable[$i]['minbaud']))    $fileString = PutLongInt($fileString, $configVariable[$i]['minbaud'], 197 + $offset);
            if (isset($configVariable[$i]['extra']))      $fileString = PutString($fileString, $configVariable[$i]['extra'], 199 + $offset, 4);
        }
        $offset = 204 * $i;
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-ChannelX.inc.php :: ReadChannels()
*
* This function will read the channelx.cfg file.
*
* @return string
*/
function ReadChannels() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/CHANNELX.CFG';
    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-ChannelX.inc.php :: WriteChannels()
*
* This function will write a new channelx.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* channelx.cfg file will become corrupt and the BBS could stop functioning!
*
* @param string $fileString
* @return mixed
*/
function WriteChannels($fileString) {
    if ($fileString === FALSE) {
        return FALSE;
    }

    if (!is_string($fileString)) {
        $fileString = (string) $fileString;
    }

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/CHANNELX.CFG';
    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the channels automatically.
$VA_CHANNELS = GetChannels();

?>