<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Download.inc.php                                               12/17/2008
 * This script will retrieve all of the informaton related to the configured
 * download protocols that are found in DOWNLOAD.CFG.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2006 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('include_dir.php');                    // Get include directory.
require_once($includeDir . 'va-functions.inc.php'); // A VADV-PHP script.


/**
* Va-Download.inc.php :: GetDownload()
*
* Retrieve all of the download protocol information and store it into a
* multidimensional array.
*
* Array format: $download[1]['setting']
*               $download[0] = Total number of download protocols.
*
* @return array
*/
function GetDownload() {
    $fileString = ReadDownload();
    if ($fileString === FALSE) {
        trigger_error(VA_Error(3));
    }

    $download = array();                    // Create the array.
    $offset   = 0;

    for ($i = 1; $offset < strlen($fileString); $i++) {
        $download[$i]['hotkey']  = GetString($fileString, 1 + $offset, 1);
        $download[$i]['desc']    = GetString($fileString, 2 + $offset, 23);
        $download[$i]['batch']   = GetChar($fileString, 25 + $offset);
        $download[$i]['command'] = GetString($fileString, 26 + $offset, 48);
        $offset = 73 * $i;
    }

    $download[0] = $i - 1;                  // Put the number of download protocols in position 0.

    return $download;                       // Return the download protocols.

}


/**
* Va-Download.inc.php :: PutDownload()
*
* This function will change the download.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]['setting'].
*
* @param string $fileString
* @param array $configVariable
* @return string
*/
function PutDownload($fileString,
                     $configVariable) {
    if ($fileString === FALSE) {
        return FALSE;
    }

    if (!is_string($fileString)) {
        $fileString = (string) $fileString;
    }
    if (!is_array($configVariable)) {
        trigger_error(VA_Error(1));
    }

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.
    $offset  = 0;

    if (isset($configVariable[0])) {
        $length--;
    }

    for ($i = 1; $pointer < $length; $i++) {
        $total = intval(strlen($fileString) / 73);
        if ($i > $total) {
            $fileString = $fileString . str_pad('', 73, chr(0));
        }

        if (isset($configVariable[$i])) {
            $pointer++;
            if (isset($configVariable[$i]['hotkey']))  $fileString = PutString($fileString, $configVariable[$i]['hotkey'], 1 + $offset, 1);
            if (isset($configVariable[$i]['desc']))    $fileString = PutString($fileString, $configVariable[$i]['desc'], 2 + $offset, 23);
            if (isset($configVariable[$i]['batch']))   $fileString = PutChar($fileString, $configVariable[$i]['batch'], 25 + $offset);
            if (isset($configVariable[$i]['command'])) $fileString = PutString($fileString, $configVariable[$i]['command'], 26 + $offset, 48);
        }
        $offset = 73 * $i;
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-Download.inc.php :: ReadDownload()
*
* This function will read the download.cfg file.
*
* @return string
*/
function ReadDownload() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/DOWNLOAD.CFG';
    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Download.inc.php :: WriteDownload()
*
* This function will write a new download.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* download.cfg file will become corrupt and the BBS could stop functioning!
*
* @param string $fileString
* @return mixed
*/
function WriteDownload($fileString) {
    if ($fileString === FALSE) {
        return FALSE;
    }

    if (!is_string($fileString)) {
        $fileString = (string) $fileString;
    }

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/DOWNLOAD.CFG';
    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the download protocols automatically.
$VA_DOWNLOAD = GetDownload();

?>